@@ -3,15 +3,8 @@ test_that("huc_12 works", {
   vcr::use_cassette("huc12_works", {
     x_1 <- huc12_summary(huc = "020700100204")
   })
-  testthat::expect_s3_class(x_1$huc_summary, "tbl_df")
-  testthat::expect_s3_class(x_1$au_summary, "tbl_df")
-  testthat::expect_s3_class(x_1$ir_summary, "tbl_df")
-  testthat::expect_s3_class(x_1$status_summary, "tbl_df")
-  testthat::expect_s3_class(x_1$use_group_summary, "tbl_df")
-  testthat::expect_s3_class(x_1$use_summary, "tbl_df")
-  testthat::expect_s3_class(x_1$param_summary, "tbl_df")
-  testthat::expect_s3_class(x_1$res_plan_summary, "tbl_df")
-  testthat::expect_s3_class(x_1$vision_plan_summary, "tbl_df")
+  testthat::expect_type(x_1, "list")
+  purrr::map(x_1, \(x) {testthat::expect_s3_class(x, "tbl_df")})
 
   vcr::use_cassette("huc12_unnest_works", {
     x_1 <- huc12_summary(huc = "020700100204",
